# invoicely

Create simple invoices.

## Description

`invoicely` lets you easily create simple invoices from python or from the command line.

## Getting started

Install using pip:

```bash
pip install invoicely
```

See `tests/test_invoicely.py` for an example of how to use the API.
